.. _Taggers:

*******
Taggers
*******

.. toctree::
   :maxdepth: 2

Taggers add :ref:`Tags` (annotations) to :ref:`Blocks` (content). These tags can be :ref:`queried <queries>` and composed later.

.. include:: ./using.rst

